import { dataStrategy } from "./dataStrategy";
import { allEventDataStrategy } from "./eventDataStrategy";
import { sightVisitorFlowByDayStrategy } from "./sightVisitorFlowByDayStrategy";
import { gateStatusStrategy } from "./gateStatusStrategy";
import { sightVisitorFlowByHourStrategy } from "./sightVisitorFlowPerHourStrategy";
import { guchengLoadStrategy } from "./guchengLoadStrategy";
import { totalVisitorFlowStrategy } from "./totalVisitorFlowStrategy";
import {totalVisitorFlowByHourStrategy} from "./totalVisitorFlowByHourStrategy";

export class strategyFactory {
    private static strategies: { [key: string]: new () => dataStrategy } = {
        'allEvents': allEventDataStrategy,
        'sightVisitorFlowByDay': sightVisitorFlowByDayStrategy,
        'gateStatus': gateStatusStrategy,
        'sightVisitorFlowPerHour': sightVisitorFlowByHourStrategy,
        'guchengLoad': guchengLoadStrategy,
        'totalVisitorFlow': totalVisitorFlowStrategy,
        'totalVisitorFlowByDay': totalVisitorFlowByHourStrategy
    };

    static createStrategy(type: string): dataStrategy {
        const StrategyClass = this.strategies[type];
        if (!StrategyClass) {
            throw new Error('Invalid strategy type');
        }
        return new StrategyClass();
    }

    static registerStrategy(type: string, strategy: new () => dataStrategy) {
        this.strategies[type] = strategy;
    }

}