import { dataStrategy } from "./dataStrategy";
import {DataExtractor} from "../../util/dataExtractor";
import excelSerialToJSDate from "../../util/excelDateToJSDate";
import mapToObj from "../../util/mapToObj";

export class totalVisitorFlowStrategy implements dataStrategy {
    extractor = DataExtractor.getInstance();
    static readonly fileName = '票务系统.xlsx';
    static readonly sheetName = '票务系统-订单主表';

    execute(params?: any): any {
        if (!params || !params.query || !params.query.date) {
            throw new Error("Data parameter is required.")
        }
        let sightData = this.extractor.getData(totalVisitorFlowStrategy.fileName, totalVisitorFlowStrategy.sheetName);
        return mapToObj(this.getTotalVisitorByDay(sightData, params.query.date));
    }

    private getTotalVisitorByDay(data: any, date: string) {
        const visitorCount: Map<string, number> = new Map();
        visitorCount.set('total', 0);

        data.forEach(row => {
            const rowDate = excelSerialToJSDate(row['游玩时间']);
            let rowDateString = '';
            try {
                rowDateString = rowDate.toISOString().split('T')[0];
            }
            catch (e) {
                rowDateString = 'invalid time'
            }
            if (rowDateString == date) {
                visitorCount.set('total', visitorCount.get('total') + 1);
                visitorCount.set(row['订单游客类型'], (visitorCount.get(row['订单游客类型']) || 0) + 1);
            }
        });

        return visitorCount;

    }

}